@@ -16,11 +16,9 @@ from __future__ import print_function
 import abc
 import os
 
-from future.utils import with_metaclass
+from six import with_metaclass
 from typing import Any, Optional, Text  # NOQA
 
-import requests_kerberos
-
 
 class Authentication(with_metaclass(abc.ABCMeta)):  # type: ignore
     @abc.abstractmethod
@@ -35,6 +33,9 @@ class Authentication(with_metaclass(abc.ABCMeta)):  # type: ignore
     def setup(self):
         pass
 
+    def get_exceptions(self):
+        return tuple()
+
     def handle_err(self, error):
         pass
 
@@ -67,6 +68,11 @@ class KerberosAuthentication(Authentication):
         pass
 
     def set_http_session(self, http_session):
+        try:
+            import requests_kerberos
+        except ImportError:
+            raise RuntimeError('unable to import requests_kerberos')
+
         if self._config:
             os.environ['KRB5_CONFIG'] = self._config
         http_session.trust_env = False
@@ -87,5 +93,12 @@ class KerberosAuthentication(Authentication):
         self.set_client_session(presto_client.client_session)
         self.set_http_session(presto_client.http_session)
 
+    def get_exceptions(self):
+        try:
+            from requests_kerberos.exceptions import KerberosExchangeError
+            return (KerberosExchangeError,)
+        except ImportError:
+            raise RuntimeError('unable to import requests_kerberos')
+
     def handle_error(self, handle_error):
         pass
