@@ -37,7 +37,6 @@ from __future__ import division
 from __future__ import print_function
 
 import os
-from requests_kerberos.exceptions import KerberosExchangeError
 from typing import Any, Dict, List, Optional, Text, Tuple, Union  # NOQA for mypy types
 
 import requests
@@ -194,6 +193,11 @@ class PrestoRequest(object):
 
     http = requests
 
+    HTTP_EXCEPTIONS = (
+        http.ConnectionError,  # type: ignore
+        http.Timeout,  # type: ignore
+    )
+
     def __init__(
         self,
         host,  # type: Text
@@ -234,11 +238,13 @@ class PrestoRequest(object):
             # mypy cannot follow module import
             self._http_session = self.http.Session()  # type: ignore
         self._http_session.headers.update(self.http_headers)
+        self._exceptions = self.HTTP_EXCEPTIONS
         self._auth = auth
         if self._auth:
             if http_scheme == constants.HTTP:
                 raise ValueError('cannot use authentication with HTTP')
             self._auth.set_http_session(self._http_session)
+            self._exceptions += self._auth.get_exceptions()
 
         self._redirect_handler = redirect_handler
         self._request_timeout = request_timeout
@@ -298,11 +304,7 @@ class PrestoRequest(object):
 
         with_retry = exceptions.retry_with(
             self._handle_retry,
-            exceptions=(
-                KerberosExchangeError,
-                PrestoRequest.http.ConnectionError,  # type: ignore
-                PrestoRequest.http.Timeout,  # type: ignore
-            ),
+            exceptions=self._exceptions,
             conditions=(
                 # need retry when there is no exception but the status code is 503
                 lambda response: getattr(response, 'status_code', None) == 503,
@@ -411,14 +413,14 @@ class PrestoRequest(object):
 
         if constants.HEADER_CLEAR_SESSION in http_response.headers:
             for prop in get_header_values(
-                response.headers,
+                http_response.headers,
                 constants.HEADER_CLEAR_SESSION,
             ):
                 self._client_session.properties.pop(prop, None)
 
         if constants.HEADER_SET_SESSION in http_response.headers:
             for key, value in get_session_property_values(
-                response.headers,
+                http_response.headers,
                 constants.HEADER_SET_SESSION,
             ):
                 self._client_session.properties[key] = value
